// A browser-compatible event emitter, from https://developer.mozilla.org/en-US/docs/Web/API/EventTarget
const EventTarget = function () {
  this.listeners = {};
};

EventTarget.prototype.listeners = null;
EventTarget.prototype.addEventListener = function (type, callback) {
  if (!(type in this.listeners)) {
    this.listeners[type] = [];
  }
  this.listeners[type].push(callback);
};

EventTarget.prototype.on = EventTarget.prototype.addEventListener;

EventTarget.prototype.removeEventListener = function (type, callback) {
  if (!(type in this.listeners)) {
    return;
  }

  let stack = this.listeners[type];
  for (let i = 0, l = stack.length; i < l; i++) {
    if (stack[i] === callback) {
      stack.splice(i, 1);
      return;
    }
  }
};

EventTarget.prototype.dispatchEvent = function (event) {
  if (!(event.type in this.listeners)) {
    return true;
  }

  let stack = this.listeners[event.type];
  event.target = this;
  for (let i = 0, l = stack.length; i < l; i++) {
    stack[i].call(this, event);
  }

  return !event.defaultPrevented;
};

module.exports = EventTarget;